Release History
---------------

0.1.1 (2015-10-23)
++++++++++++++++++

- Fixed bug that caused infinite loop if input FASTA alignment was incorrect and
  primer4clades could not generate primers for.

0.1.0 (2015-10-22)
++++++++++++++++++

- Add taxon name to description of FASTA seqs if given by user.

0.0.1 (2015-10-22)
++++++++++++++++++

- Some refactoring and testing.
- Updated requirements.
- Added test rule to Makefile.
- Small fixes of style to code.
- Replaced name of changelog to history.

0.0.0 (2015-10-06)
++++++++++++++++++

- First release on PyPI.
